@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -479,8 +479,8 @@ CSFML_GRAPHICS_API void sfRenderWindow_drawVertexBuffer(sfRenderWindow* renderWi
 ////////////////////////////////////////////////////////////
 /// \brief Draw primitives defined by a vertex buffer.
 ///
-/// \param renderWindow render window object
-/// \param vertexBuffer Vertex buffer object to draw
+/// \param renderWindow Render window object
+/// \param object       Vertex buffer object to draw
 /// \param firstVertex  Index of the first vertex to render
 /// \param vertexCount  Number of vertices to render
 /// \param states       Render states to use for drawing
@@ -618,5 +618,18 @@ CSFML_GRAPHICS_API void sfMouse_setPositionRenderWindow(sfVector2i position, con
 ////////////////////////////////////////////////////////////
 CSFML_GRAPHICS_API sfVector2i sfTouch_getPositionRenderWindow(unsigned int finger, const sfRenderWindow* relativeTo);
 
+////////////////////////////////////////////////////////////
+/// \brief Create a Vulkan rendering surface
+///
+/// \param renderWindow RenderWindow object
+/// \param instance     Vulkan instance
+/// \param surface      Created surface
+/// \param allocator    Allocator to use
+///
+/// \return True if surface creation was successful, false otherwise
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API sfBool sfRenderWindow_createVulkanSurface(sfRenderWindow* renderWindow, const VkInstance* instance, VkSurfaceKHR* surface, const VkAllocationCallbacks* allocator);
+
 
 #endif // SFML_RENDERWINDOW_H
