@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -445,7 +445,7 @@ CSFML_GRAPHICS_API float sfText_getLetterSpacing(const sfText* text);
 /// \see sfText_setLineSpacing
 ///
 ////////////////////////////////////////////////////////////
-CSFML_GRAPHICS_API float getLineSpacing(const sfText* text);
+CSFML_GRAPHICS_API float sfText_getLineSpacing(const sfText* text);
 
 ////////////////////////////////////////////////////////////
 /// \brief Get the style of a text
