@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,6 +26,7 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Mouse.h>
+#include <SFML/Window/WindowBaseStruct.h>
 #include <SFML/Window/WindowStruct.h>
 #include <SFML/Window/Mouse.hpp>
 #include <SFML/Internal.h>
@@ -60,3 +61,27 @@ void sfMouse_setPosition(sfVector2i position, const sfWindow* relativeTo)
     else
         sf::Mouse::setPosition(sf::Vector2i(position.x, position.y));
 }
+
+
+////////////////////////////////////////////////////////////
+sfVector2i sfMouse_getPositionWindowBase(const sfWindowBase* relativeTo)
+{
+    sf::Vector2i sfmlPos;
+    if (relativeTo)
+        sfmlPos = sf::Mouse::getPosition(relativeTo->This);
+    else
+        sfmlPos = sf::Mouse::getPosition();
+
+    sfVector2i position = { sfmlPos.x, sfmlPos.y };
+    return position;
+}
+
+
+////////////////////////////////////////////////////////////
+void sfMouse_setPositionWindowBase(sfVector2i position, const sfWindowBase* relativeTo)
+{
+    if (relativeTo)
+        sf::Mouse::setPosition(sf::Vector2i(position.x, position.y), relativeTo->This);
+    else
+        sf::Mouse::setPosition(sf::Vector2i(position.x, position.y));
+}
