@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,6 +27,7 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Touch.h>
 #include <SFML/Window/Touch.hpp>
+#include <SFML/Window/WindowBaseStruct.h>
 #include <SFML/Window/WindowStruct.h>
 #include <SFML/Internal.h>
 
@@ -51,3 +52,16 @@ sfVector2i sfTouch_getPosition(unsigned int finger, const sfWindow* relativeTo)
     return position;
 }
 
+////////////////////////////////////////////////////////////
+sfVector2i sfTouch_getPositionWindowBase(unsigned int finger, const sfWindowBase* relativeTo)
+{
+    sf::Vector2i sfmlPosition;
+
+    if (relativeTo)
+        sfmlPosition = sf::Touch::getPosition(finger, relativeTo->This);
+    else
+        sfmlPosition = sf::Touch::getPosition(finger);
+
+    sfVector2i position = { sfmlPosition.x, sfmlPosition.y };
+    return position;
+}
